pydna.py_rstr_max package — Pydna 0.6.2 documentation

### Navigation

- index
- modules |
- modules |
- previous |
- Pydna 0.6.2 documentation »
- pydna package »

# pydna.py_rstr_max package

## Submodules

## pydna.py_rstr_max.rstr_max module

class `pydna.py_rstr_max.rstr_max.` `Rstr_max`
  `add_str`(str_unicode)
  `go`()
  `removeMany`(stack, results, m, idxEnd)
  `step1_sort_suffix`()
  `step2_lcp`()
  `step3_rstr`()

## pydna.py_rstr_max.tools_karkkainen_sanders module

`pydna.py_rstr_max.tools_karkkainen_sanders.` `LCP`(s, suffix_array)

`pydna.py_rstr_max.tools_karkkainen_sanders.` `direct_kark_sort`(s)

`pydna.py_rstr_max.tools_karkkainen_sanders.` `kark_sort`(s, SA, n, K)

`pydna.py_rstr_max.tools_karkkainen_sanders.` `radixpass`(a, b, r, s, n, k)

`pydna.py_rstr_max.tools_karkkainen_sanders.` `simple_kark_sort`(s)

## Module contents

### Navigation

- index
- modules |
- modules |
- previous |
- Pydna 0.6.2 documentation »
- pydna package »